Release Notes — dicom_parser 0.0.1 documentation

# Release Notes

## 0.1.3

> - Changed Code String (CS) parsing to return verbose value or set of values using the `code_strings` module. This feature can be disabled by setting the `Parser`’s verbose_code_strings attribute to False.

> - Added warnings for invalid pixel arrays and invalid Code String (CS) values.

> - Updated the `sequences` class to work with verbose Code String (CS) data element values and renamed known MR sequences.

> - Refactored the `Parser` class to a bit to improve readability.

## 0.1.2

> - Improved private tags definition so that the `Header` model’s `get()` method will work using the private tag’s keyword.

> - Added support for calling len() over a `Series` instance to return the number of images in it.

> - Added support for querying header information from a `Series` instance using the `get()` method or the indexing operator ([]) using a str or a tuple.

> - Added support for indexing the `Image` instances from a `Series` using an int or slice.

## 0.1.1

> - Improved support for accessing CSA headers.

> - Added auto-decoding for Siemens mosaic encoded data (applies to data extraction in both `Image` and `Series` instances).

>   > - The decoding method also changes the orientation of the stacked arrays to match the product of conversion to NIfTI using dcm2niix.

## 0.1.0

First release!

> - Type correction based on value-representation (VR).

> - Simple `Series` class for reading DICOM series directories.

> - Basic support for reading CSA headers using the `CsaHeader` class.